local E, L, V, P, G = unpack(ElvUI)
local IsAddOnLoaded = IsAddOnLoaded
local format = string.format
local MyPluginName = "GennUI"
local GNUI = E:GetModule("GennUI");
local classColor = E:ClassColor(E.myclass, true)

--[[ Profile Check ]]--
function GNUI:ProfileCheck(new)
	if (new) then
		StaticPopupDialogs["CreateProfileNameNew"] = {
		text = L["Name for the new profile"],
		button1 = L["Accept"],
		button2 = L["Cancel"],
		hasEditBox = 1,
		whileDead = 1,
		hideOnEscape = 1,
		timeout = 0,
		OnShow = function(self, data)
		  self.editBox:SetText(E.mynameRealm);
		end,
		OnAccept = function(self, data, data2)
		  local text = self.editBox:GetText()
		  ElvUI[1].data:SetProfile(text)
		  E:Print(L["Profile created"])
		  PluginInstallStepComplete.message = "Profile Created"
		  PluginInstallStepComplete:Show()
		  PluginInstallFrame.Desc3:SetText("Your currently active profile is: |cffc31f3b"..ElvUI[1].data:GetCurrentProfile().."|r")
		end
	  };
	  StaticPopup_Show("CreateProfileNameNew", profileKey);
	elseif (new == false) then
		StaticPopupDialogs["ProfileOverwriteConfirm"] = {
			text = "Are you sure you want to overwrite the current profile?",
			button1 = "Yes",
			button2 = "No",
			OnAccept = function()
				E:Print(L["Current Profile Selected"])
			    PluginInstallStepComplete.message = "Current Profile Selected"
		        PluginInstallStepComplete:Show()
			end,
			timeout = 0,
			whileDead = true,
			hideOnEscape = true,
		}
		StaticPopup_Show("ProfileOverwriteConfirm", profileKey)
	end
end

--[[ Setup Layout ]]--
function GNUI:SetupLayout()
	GNUI:SetupActionBars()
	GNUI:SetupAuras()
	GNUI:SetupBags()
	GNUI:SetupDataBars()
	GNUI:SetupDataTexts()
	GNUI:SetupGlobalPrivate()
	GNUI:SetupMovers()
	GNUI:SetupNameplates()
	GNUI:SetupTooltip()
	GNUI:SetupUnitframes()
	
	-- AddOnSkins
	GNUI:LoadASProfile()
	-- Shadow & Light
	GNUI:LoadSLEProfile()
	-- WindTools
	GNUI:LoadWTProfile()

-- Update ElvUI
	E:StaggeredUpdateAll(nil, true)
	E:Print(L["|cffc31f3bGennUI |cfffffffflayout has been set"])
	PluginInstallStepComplete.message = "GennUI Layout has been set"
	PluginInstallStepComplete:Show()
end

-- Minimum Update
function GNUI:MinUpdate()

--- Custom Texts
E.db["unitframe"]["units"]["player"]["customTexts"] = E.db["unitframe"]["units"]["player"]["customTexts"] or {}
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"] = {}
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"] = {}
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"] = {}
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"] = {}
E.db["unitframe"]["units"]["target"]["customTexts"] = E.db["unitframe"]["units"]["target"]["customTexts"] or {}
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"] = {}
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"] = {}
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"] = {}
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"] = {}
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"] = {}	
E.db["unitframe"]["units"]["boss"]["customTexts"] = E.db["unitframe"]["units"]["boss"]["customTexts"] or {}
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"] = {}
E.db["unitframe"]["units"]["boss"]["customTexts"]["gPower"] = {}
E.db["unitframe"]["units"]["arena"]["customTexts"] = E.db["unitframe"]["units"]["arena"]["customTexts"] or {}
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"] = {}
E.db["unitframe"]["units"]["party"]["customTexts"] = E.db["unitframe"]["units"]["party"]["customTexts"] or {}
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"] = {}
E.db["unitframe"]["units"]["party"]["customTexts"]["gHealth"] = {}
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"] = {}

-- Arena
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["attachTextTo"] = "Frame"
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["enable"] = true
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["font"] = "Futura PT Medium"
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["size"] = 18
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["text_format"] = "[name:medium]"
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["xOffset"] = 0
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["yOffset"] = 6

-- Boss
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["attachTextTo"] = "Frame"
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["enable"] = true
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["font"] = "Futura PT Medium"
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["size"] = 18
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["text_format"] = "[name:abbrev:medium]"
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["xOffset"] = 0
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["yOffset"] = 6
E.db["unitframe"]["units"]["boss"]["customTexts"]["gPower"]["attachTextTo"] = "Power"
E.db["unitframe"]["units"]["boss"]["customTexts"]["gPower"]["enable"] = false
E.db["unitframe"]["units"]["boss"]["customTexts"]["gPower"]["font"] = "Futura PT Medium"
E.db["unitframe"]["units"]["boss"]["customTexts"]["gPower"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["boss"]["customTexts"]["gPower"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["boss"]["customTexts"]["gPower"]["size"] = 12
E.db["unitframe"]["units"]["boss"]["customTexts"]["gPower"]["text_format"] = "[powercolor][power:current:shortvalue]"
E.db["unitframe"]["units"]["boss"]["customTexts"]["gPower"]["xOffset"] = 26
E.db["unitframe"]["units"]["boss"]["customTexts"]["gPower"]["yOffset"] = 0

-- Party
E.db["unitframe"]["units"]["party"]["customTexts"]["gHealth"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["party"]["customTexts"]["gHealth"]["enable"] = true
E.db["unitframe"]["units"]["party"]["customTexts"]["gHealth"]["font"] = "Futura PT Medium"
E.db["unitframe"]["units"]["party"]["customTexts"]["gHealth"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["party"]["customTexts"]["gHealth"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["party"]["customTexts"]["gHealth"]["size"] = 14
E.db["unitframe"]["units"]["party"]["customTexts"]["gHealth"]["text_format"] = "[health:current:shortvalue]"
E.db["unitframe"]["units"]["party"]["customTexts"]["gHealth"]["xOffset"] = 0
E.db["unitframe"]["units"]["party"]["customTexts"]["gHealth"]["yOffset"] = -8
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["attachTextTo"] = "Frame"
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["enable"] = true
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["font"] = "Futura PT Medium"
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["size"] = 10
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["text_format"] = "|cff00d1ff[gnuihmana]"
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["xOffset"] = 0
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["yOffset"] = 8
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["attachTextTo"] = "Frame"
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["enable"] = true
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["font"] = "Futura PT Medium"
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["justifyH"] = "LEFT"
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["size"] = 16
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["text_format"] = "[name:medium]"
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["xOffset"] = 0
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["yOffset"] = 6

-- Player
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["attachTextTo"] = "Frame"
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["enable"] = true
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["font"] = "Futura PT Medium"
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["size"] = 18
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["text_format"] = "[health:current:shortvalue]"
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["xOffset"] = 0
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["yOffset"] = -6
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["attachTextTo"] = "Frame"
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["enable"] = true
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["font"] = "Futura PT Medium"
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["size"] = 11
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["text_format"] = "|cff00d1ff[gnuihmana]"
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["xOffset"] = 0
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["yOffset"] = 8
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["attachTextTo"] = "Frame"
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["enable"] = true
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["font"] = "Futura PT Medium"
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["justifyH"] = "LEFT"
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["size"] = 18
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["text_format"] = "[name:long]"
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["xOffset"] = 0
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["yOffset"] = 5
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["attachTextTo"] = "Frame"
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["enable"] = true
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["font"] = "Futura PT Medium"
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["justifyH"] = "LEFT"
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["size"] = 12
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["text_format"] = "[powercolor][power:current:shortvalue]"
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["xOffset"] = 0
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["yOffset"] = -10

-- Target
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["attachTextTo"] = "Frame"
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["enable"] = true
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["font"] = "Futura PT Medium"
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["justifyH"] = "LEFT"
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["size"] = 18
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["text_format"] = "[health:current:shortvalue]"
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["xOffset"] = 0
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["yOffset"] = -6
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["attachTextTo"] = "Frame"
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["enable"] = true
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["font"] = "Futura PT Medium"
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["justifyH"] = "CENTER"
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["size"] = 12
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["text_format"] = "[namecolor][smartclass] ||cffffffff LvL ||r[difficultycolor][level] [classification]"
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["xOffset"] = 0
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["yOffset"] = -24
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["attachTextTo"] = "Frame"
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["enable"] = true
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["font"] = "Futura PT Medium"
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["size"] = 18
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["text_format"] = "[name:abbrev:long]"
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["xOffset"] = 0
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["yOffset"] = 5
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["attachTextTo"] = "Frame"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["enable"] = true
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["justifyH"] = "LEFT"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["size"] = 10
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["text_format"] = "[perhp]%"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["xOffset"] = 0
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["yOffset"] = 8
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["attachTextTo"] = "Frame"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["enable"] = true
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["font"] = "Futura PT Medium"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["size"] = 12
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["text_format"] = "[powercolor][power:current:shortvalue]"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["xOffset"] = 0
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["yOffset"] = -8

end